<?php

namespace Pinpoint\DeliveryDate\Setup;

use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;


/**
 * @codeCoverageIgnore
 */
class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * {@inheritdoc}
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        if (version_compare($context->getVersion(), '0.0.2', '<')) {
             $this->changeUpdatedWeekdaysColumnName($setup);
        }

        if (version_compare($context->getVersion(), '0.0.3', '<')) {
            $this->addDescriptionColumn($setup);
        }

        $setup->endSetup();
    }

    /**
     * @param \Magento\Framework\Setup\SchemaSetupInterface $setup
     */
    protected function changeUpdatedWeekdaysColumnName(\Magento\Framework\Setup\SchemaSetupInterface $setup)
    {
        $installer = $setup;
        $tableName = $installer->getTable('pinpoint_deliverydate_estimated_dates');

        $installer->getConnection()->changeColumn(
            $tableName,
            'excluding_weekdays',
            'excluding_days',
            [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                'length' => 255,
                'comment' => 'days to be excluded'
            ]
        );
    }

    private function addDescriptionColumn($setup)
    {
        $installer = $setup;
        $tableName = $installer->getTable('pinpoint_deliverydate_estimated_dates');

        $installer->getConnection()->addColumn(
            $tableName,
            'description',
            [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                'length' => 255,
                'comment' => 'Description'
            ]
        );
    }
}
